@@ -1,6 +1,7 @@
 package main
 
 import (
+	"fmt"
 	"os"
 	"os/signal"
 	"syscall"
@@ -17,12 +18,12 @@ import (
 type AgentSettings struct {
 	PrometheusOnly bool `long:"listen-prometheus-only" description:"listen only for Prometheus requests" env:"STORK_AGENT_LISTEN_PROMETHEUS_ONLY"`
 	StorkOnly      bool `long:"listen-stork-only" description:"listen only for Stork Server requests" env:"STORK_AGENT_LISTEN_STORK_ONLY"`
+	Version        bool `short:"v" long:"version" description:"show software version"`
 }
 
 func main() {
 	// Setup logging
 	storkutil.SetupLogging()
-	log.Printf("Starting Stork Agent, version %s, build date %s", stork.Version, stork.BuildDate)
 
 	// Start app monitor
 	appMonitor := agent.NewAppMonitor()
@@ -61,9 +62,21 @@ func main() {
 				os.Exit(0)
 			}
 		}
-		log.Fatalf("FATAL error: %+v", err)
+		log.Fatalf("FATAL error during parsing: %+v", err)
 	}
 
+	if agentSettings.Version {
+		// If user specified --version or -v, print the version and quit.
+		fmt.Printf("%s\n", stork.Version)
+		os.Exit(0)
+	}
+
+	// We need to print this statement only after we check if the only purpose is to print a version.
+	log.Printf("Starting Stork Agent, version %s, build date %s", stork.Version, stork.BuildDate)
+
+	// Let's start the app monitor.
+	appMonitor.Start()
+
 	// Only start the exporters if they're enabled.
 	if !agentSettings.StorkOnly {
 		promKeaExporter.Start()
