@@ -2,6 +2,7 @@ package agentcomm
 
 import (
 	"context"
+	"fmt"
 	"sync"
 
 	"github.com/pkg/errors"
@@ -15,11 +16,40 @@ import (
 type AgentsSettings struct {
 }
 
-// Runtime information about the agent, e.g. connection.
+// Holds runtime communication statistics with Kea daemons via
+// a given agent.
+type AgentKeaCommStats struct {
+	CurrentErrorsCA      int64
+	CurrentErrorsDaemons map[string]int64
+}
+
+// Holds runtime communication statistics with Bind9 daemon for
+// a given agent.
+type AgentBind9CommStats struct {
+	CurrentErrorsRNDC  int64
+	CurrentErrorsStats int64
+}
+
+type AppCommStatsKey struct {
+	Address string
+	Port    int64
+}
+
+// Holds runtime statistics of communication with a given agent and
+// with the apps behind this agent.
+type AgentStats struct {
+	CurrentErrors int64
+	AppCommStats  map[AppCommStatsKey]interface{}
+	mutex         *sync.Mutex
+}
+
+// Runtime information about the agent, e.g. connection, communication
+// statistics.
 type Agent struct {
 	Address  string
 	Client   agentapi.AgentClient
 	GrpcConn *grpc.ClientConn
+	Stats    AgentStats
 }
 
 // Prepare gRPC connection to agent.
@@ -48,10 +78,11 @@ func (agent *Agent) MakeGrpcConnection() error {
 type ConnectedAgents interface {
 	Shutdown()
 	GetConnectedAgent(address string) (*Agent, error)
+	GetConnectedAgentStats(adddress string, port int64) *AgentStats
 	GetState(ctx context.Context, address string, agentPort int64) (*State, error)
 	ForwardRndcCommand(ctx context.Context, agentAddress string, agentPort int64, rndcSettings Bind9Control, command string) (*RndcOutput, error)
-	ForwardToNamedStats(ctx context.Context, agentAddress string, agentPort int64, statsURL string, statsOutput interface{}) error
-	ForwardToKeaOverHTTP(ctx context.Context, agentAddress string, agentPort int64, caURL string, commands []*KeaCommand, cmdResponses ...interface{}) (*KeaCmdsResult, error)
+	ForwardToNamedStats(ctx context.Context, agentAddress string, agentPort int64, statsAddress string, statsPort int64, path string, statsOutput interface{}) error
+	ForwardToKeaOverHTTP(ctx context.Context, agentAddress string, agentPort int64, caAddress string, caPort int64, commands []*KeaCommand, cmdResponses ...interface{}) (*KeaCmdsResult, error)
 }
 
 // Agents management map. It tracks Agents currently connected to the Server.
@@ -97,13 +128,17 @@ func (agents *connectedAgentsData) GetConnectedAgent(address string) (*Agent, er
 	// Look for agent in Agents map and if found then return it
 	agent, ok := agents.AgentsMap[address]
 	if ok {
-		log.Printf("connecting to existing agent on %v", address)
+		log.WithFields(log.Fields{
+			"address": address,
+		}).Info("connecting to existing agent")
 		return agent, nil
 	}
 
 	// Agent not found so allocate agent and prepare connection
 	agent = new(Agent)
 	agent.Address = address
+	agent.Stats.AppCommStats = make(map[AppCommStatsKey]interface{})
+	agent.Stats.mutex = new(sync.Mutex)
 	err := agent.MakeGrpcConnection()
 	if err != nil {
 		return nil, err
@@ -111,7 +146,22 @@ func (agents *connectedAgentsData) GetConnectedAgent(address string) (*Agent, er
 
 	// Store it in Agents map
 	agents.AgentsMap[address] = agent
-	log.Printf("connecting to new agent on %v", address)
+	log.WithFields(log.Fields{
+		"address": address,
+	}).Info("connecting to new agent")
 
 	return agent, nil
 }
+
+// Returns statistics for the connected agent. The statistics include number
+// of errors to communicate with the agent and the number of errors to
+// communicate with the apps behind the agent.
+func (agents *connectedAgentsData) GetConnectedAgentStats(address string, port int64) *AgentStats {
+	if port != 0 {
+		address = fmt.Sprintf("%s:%d", address, port)
+	}
+	if agent, ok := agents.AgentsMap[address]; ok {
+		return &agent.Stats
+	}
+	return nil
+}
