@@ -67,8 +67,9 @@ func (c *DatabaseSettings) PgParams() *PgOptions {
 // Fetches database password from the environment variable or prompts the user
 // for the password.
 func Password(settings *DatabaseSettings) {
-	settings.Password = os.Getenv("STORK_DATABASE_PASSWORD")
-	if len(settings.Password) == 0 {
+	if passwd, ok := os.LookupEnv("STORK_DATABASE_PASSWORD"); ok {
+		settings.Password = passwd
+	} else {
 		// Prompt the user for database password.
 		fmt.Printf("database password: ")
 		pass, err := terminal.ReadPassword(0)
