@@ -35,35 +35,6 @@ export class AppComponent implements OnInit {
     ) {
         this.initMenus()
 
-        this.auth.currentUser.subscribe((x) => {
-            this.currentUser = x
-            if (this.auth.superAdmin()) {
-                // super admin can see Configuration/Users menu
-                this.menuItems[2].items[0]['visible'] = true
-            } else {
-                this.menuItems[2].items[0]['visible'] = false
-            }
-        })
-
-        this.serverData.getAppsStats().subscribe((data) => {
-            // if there are Kea apps then show Kea related menu items
-            // otherwise hide them
-            if (data.keaAppsTotal && data.keaAppsTotal > 0) {
-                this.menuItems[0].visible = true
-                this.menuItems[1].items[0]['visible'] = true
-            } else {
-                this.menuItems[0].visible = false
-                this.menuItems[1].items[0]['visible'] = false
-            }
-            // if there are BIND 9 apps then show BIND 9 related menu items
-            // otherwise hide them
-            if (data.bind9AppsTotal && data.bind9AppsTotal > 0) {
-                this.menuItems[1].items[1]['visible'] = true
-            } else {
-                this.menuItems[1].items[1]['visible'] = false
-            }
-        })
-
         this.loadingInProgress = this.loadingService.getState()
     }
 
@@ -185,25 +156,57 @@ export class AppComponent implements OnInit {
             this.storkBuildDate = data.date
         })
 
-        // If Grafana url is not empty, we need to make
-        // Services.Grafana menu choice visible and set it's url.
-        // Otherwise we need to make sure it's not visible.
-        this.settingSvc.getSettings().subscribe((data) => {
-            const grafanaUrl = data['grafana_url']
+        this.auth.currentUser.subscribe((x) => {
+            this.currentUser = x
+            if (this.auth.superAdmin()) {
+                // super admin can see Configuration/Users menu
+                this.menuItems[2].items[0]['visible'] = true
+            } else {
+                this.menuItems[2].items[0]['visible'] = false
+            }
 
-            for (const menuItem of this.menuItems) {
-                if (menuItem['label'] === 'Services') {
-                    for (const subMenu of menuItem.items) {
-                        if (subMenu['label'] === 'Grafana') {
-                            if (grafanaUrl && grafanaUrl !== '') {
-                                subMenu['visible'] = true
-                                subMenu['url'] = grafanaUrl
-                            } else {
-                                subMenu['visible'] = false
+            // Only get the stats and settings when the user is logged in.
+            if (this.auth.currentUserValue) {
+                this.serverData.getAppsStats().subscribe((data) => {
+                    // if there are Kea apps then show Kea related menu items
+                    // otherwise hide them
+                    if (data.keaAppsTotal && data.keaAppsTotal > 0) {
+                        this.menuItems[0].visible = true
+                        this.menuItems[1].items[0]['visible'] = true
+                    } else {
+                        this.menuItems[0].visible = false
+                        this.menuItems[1].items[0]['visible'] = false
+                    }
+                    // if there are BIND 9 apps then show BIND 9 related menu items
+                    // otherwise hide them
+                    if (data.bind9AppsTotal && data.bind9AppsTotal > 0) {
+                        this.menuItems[1].items[1]['visible'] = true
+                    } else {
+                        this.menuItems[1].items[1]['visible'] = false
+                    }
+                })
+
+                // If Grafana url is not empty, we need to make
+                // Services.Grafana menu choice visible and set it's url.
+                // Otherwise we need to make sure it's not visible.
+                this.settingSvc.getSettings().subscribe((data) => {
+                    const grafanaUrl = data['grafana_url']
+
+                    for (const menuItem of this.menuItems) {
+                        if (menuItem['label'] === 'Services') {
+                            for (const subMenu of menuItem.items) {
+                                if (subMenu['label'] === 'Grafana') {
+                                    if (grafanaUrl && grafanaUrl !== '') {
+                                        subMenu['visible'] = true
+                                        subMenu['url'] = grafanaUrl
+                                    } else {
+                                        subMenu['visible'] = false
+                                    }
+                                }
                             }
                         }
                     }
-                }
+                })
             }
         })
     }
