@@ -4,7 +4,15 @@ import { MessageService } from 'primeng/api'
 
 import { DHCPService } from '../backend/api/api'
 import { AppsStats } from '../backend/model/appsStats'
-import { datetimeToLocal, durationToString, getGrafanaUrl, humanCount } from '../utils'
+import {
+    datetimeToLocal,
+    durationToString,
+    getGrafanaUrl,
+    humanCount,
+    daemonStatusIconName,
+    daemonStatusIconColor,
+    daemonStatusIconTooltip,
+} from '../utils'
 import { SettingService } from '../setting.service'
 import { ServerDataService } from '../server-data.service'
 
@@ -135,6 +143,49 @@ export class DashboardComponent implements OnInit {
         return getGrafanaUrl(this.grafanaUrl, name, subnet, instance)
     }
 
+    /**
+     * Returns the name of the icon to be used in the Status column
+     *
+     * The icon selected depends on whether the daemon is active or not
+     * active and whether there is a communication with the daemon or
+     * not.
+     *
+     * @param daemon data structure holding the information about the daemon.
+     *
+     * @returns ban icon if the daemon is not active, times icon if the daemon
+     *          should be active but the communication with it is borken and
+     *          check icon if the communication with the active daemon is ok.
+     */
+    daemonStatusIconName(daemon) {
+        return daemonStatusIconName(daemon)
+    }
+
+    /**
+     * Returns the color of the icon used in the Status column
+     *
+     * @param daemon data structure holding the information about the daemon.
+     *
+     * @returns grey color if the daemon is not active, red if the daemon is
+     *          active but there are communication issues, green if the
+     *          communication with the active daemon is ok.
+     */
+    daemonStatusIconColor(daemon) {
+        return daemonStatusIconColor(daemon)
+    }
+
+    /**
+     * Returns tooltip for the icon presented in the Status column
+     *
+     * @param daemon data structure holding the information about the daemon.
+     *
+     * @returns Tooltip as text. It includes hints about the communication
+     *          problems when such problems occur, e.g. it includes the
+     *          hint whether the communication is with the agent or daemon.
+     */
+    daemonStatusIconTooltip(daemon) {
+        return daemonStatusIconTooltip(daemon)
+    }
+
     /**
      * Returns the name of the icon to be shown for the given HA state
      *
